/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *     "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache" or
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.jetspeed.modules.pages;


// Jetspeed classes
import org.apache.jetspeed.util.template.JetspeedTemplateNavigation;

// Turbine Utility Classes
import org.apache.turbine.util.RunData;
import org.apache.turbine.services.jsp.JspService;
import org.apache.turbine.services.TurbineServices;
import org.apache.turbine.services.velocity.VelocityService;
import org.apache.turbine.services.velocity.TurbineVelocity;
import org.apache.velocity.context.Context;

/**
 * Same as turbine's JspPage, only that it extends JetspeedTemplatePage.
 * Adds some convenience objects to the request.
 *
 * @author <a href="mailto:ingo@raleigh.ibm.com">Ingo Schuster</a>
 * @version $Revision: 1.6 $      
 */
public class JetspeedJspPage extends JetspeedTemplatePage
{ 

    /**
     * Same method as in turbine's JspPage
     * Stuffs some useful objects into the request so that 
     * it is available to the Action module and the Screen module
     */  
    protected void doBuildBeforeAction(RunData data) throws Exception
    {
        super.doBuildBeforeAction( data);
        JspService jsp = (JspService)TurbineServices.getInstance()
            .getService(JspService.SERVICE_NAME);
                
        jsp.addDefaultObjects(data);

        data.getResponse().setBufferSize(jsp.getDefaultBufferSize());

        // FIXME: this tools are now in TR.p file, as standard request tools instantiated by turbine.
        // All tools but jnavigation are there, jnavigation need to be instantiated here
        // because TemplateNavigation in which depends does have a no args constructor..and
        // turbine need one to be able to instantiate such class as request tool
        Context context = TurbineVelocity.getContext(data);
        TurbineVelocity.getContext(data).put("jnavigation", new JetspeedTemplateNavigation(data));
        data.getTemplateInfo().setTemplateContext(VelocityService.CONTEXT, context);

    }

}
