/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2003 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *     "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache" or
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.jetspeed.util;

import org.apache.jetspeed.om.profile.Portlets;
import org.apache.jetspeed.om.profile.Entry;
import org.apache.jetspeed.om.profile.Reference;
import org.apache.jetspeed.services.idgenerator.JetspeedIdGenerator;

// Jetspeed
import org.apache.jetspeed.om.profile.Profile;
import org.apache.jetspeed.services.security.PortalResource;
import org.apache.jetspeed.om.security.JetspeedUser;
import org.apache.jetspeed.services.JetspeedSecurity;

// Turbine stuff
import org.apache.turbine.util.RunData;

/**
 * This class provides static util methods for portlet manipulation that 
 * aren't part of the default services.
 *
 * @author <a href="mailto:morciuch@apache.org">Mark Orciuch</a> 
 * @version $Id: PortletUtils.java,v 1.3 2003/06/04 15:59:13 morciuch Exp $
 */
public class PortletUtils 
{
    /**
     * Regenerates jspeid for all portlets, entries and references
     *
     * @param profile Profile to process
     * @return Profile with portlet ids regenerated
     */
    public static void regenerateIds(Portlets topPortlets)
    throws Exception
    {
        // Display some portlets
        Portlets[] portlets = topPortlets.getPortletsArray();
        for (int i = 0; i < portlets.length; i++)
        {
            portlets[i].setId(JetspeedIdGenerator.getNextPeid());
            
            Entry[] entries = portlets[i].getEntriesArray();
            for (int j = 0; j < entries.length; j++)
            {
                entries[j].setId(JetspeedIdGenerator.getNextPeid());
            }

            Reference[] refs = portlets[i].getReferenceArray();
            for (int k = 0; k < refs.length; k++)
            {
                refs[k].setId(JetspeedIdGenerator.getNextPeid());
            }

            regenerateIds(portlets[i]);
        }
    }

    /**
     * Returns true if specific profile is accessible by the current user
     * 
     * @param data
     * @param profile
     * @return 
     */
    public static boolean canAccessProfile(RunData rundata, Profile profile)
    {
        boolean result = true;

        if (profile != null && profile.getRootSet() != null)
        {
            PortalResource portalResource = new PortalResource(profile.getRootSet());
            String owner = null;
            if (profile.getUserName() != null)
            {
                owner = profile.getUserName();
            }
            portalResource.setOwner(owner);

            result = JetspeedSecurity.checkPermission((JetspeedUser) rundata.getUser(), 
                                                      portalResource, 
                                                      JetspeedSecurity.PERMISSION_CUSTOMIZE);
        }

        return result;

    }

}
